@@ -8,9 +8,10 @@ use Path::Tiny qw( path );
 use JSON::PP qw( decode_json );
 use Alien::Build::Plugin;
 use Alien::Build::Plugin::Download::Negotiate;
+use Alien::Build::Plugin::Extract::Negotiate;
 
 # ABSTRACT: Alien::Build plugin to download from GitHub
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 has github_user => sub { croak("github_user is required") };
@@ -51,7 +52,7 @@ sub init
         }
         elsif($res->{path})
         {
-          $rel = path($res->{path})->slurp_utf8;
+          $rel = decode_json path($res->{path})->slurp_utf8;
         }
         else
         {
@@ -61,10 +62,12 @@ sub init
           type => 'list',
           list => [
             map {
+              my $release = $_;
+              my($version) = $release->{tag_name} =~ $self->version;
               my %h = (
-                filename => $_->{tag_name},
-                url      => $_->{tarball_url},
-                version  => $_->{tag_name},
+                filename => $release->{tag_name},
+                url      => $release->{tarball_url},
+                defined $version ? (version  => $version) : (),
               );
               \%h;
             } @$rel
@@ -104,7 +107,7 @@ Alien::Build::Plugin::Download::GitHub - Alien::Build plugin to download from Gi
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -164,6 +167,13 @@ GitHub repositories.  This is the default.
 
 =back
 
+=head1 CAVEATS
+
+The GitHub API is rate limited.  The unauthenticated API is especially so.  This may
+render this plugin inoperative for a short time after only a little testing.  Please see
+
+L<https://github.com/Perl5-Alien/Alien-Build-Plugin-Download-GitHub/issues/3>
+
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
